@@ -2,13 +2,13 @@
 
 """Module containing the AcpypeParamsGMX class and the command line interface."""
 import argparse
+from biobb_common.generic.biobb_object import BiobbObject
 from biobb_common.configuration import  settings
-from biobb_common.tools import file_utils as fu
 from biobb_common.tools.file_utils import launchlogger
-from biobb_common.command_wrapper import cmd_wrapper
 from biobb_chemistry.acpype.common import *
 
-class AcpypeParamsGMX():
+
+class AcpypeParamsGMX(BiobbObject):
     """
     | biobb_chemistry AcpypeParamsGMX
     | This class is a wrapper of `Acpype <https://github.com/alanwilter/acpype>`_ tool for generation of topologies for GROMACS.
@@ -22,11 +22,11 @@ class AcpypeParamsGMX():
         properties (dic - Python dictionary object containing the tool parameters, not input/output files):
             * **basename** (*str*) - ("BBB") A basename for the project (folder and output files).
             * **charge** (*int*) - (0) [-20~20|1] Net molecular charge, for gas default is 0. If None the charge is guessed by acpype.
-            * **acpype_path** (*str*) - ("acpype") Path to the acpype executable binary.
+            * **binary_path** (*str*) - ("acpype") Path to the acpype executable binary.
             * **remove_tmp** (*bool*) - (True) [WF property] Remove temporal files.
             * **restart** (*bool*) - (False) [WF property] Do not execute if output files exist.
             * **container_path** (*str*) - (None) Container path definition.
-            * **container_image** (*str*) - ('mmbirb/acpype:latest') Container image definition.
+            * **container_image** (*str*) - ('acpype/acpype:2022.7.21') Container image definition.
             * **container_volume_path** (*str*) - ('/tmp') Container volume path definition.
             * **container_working_dir** (*str*) - (None) Container working directory definition.
             * **container_user_id** (*str*) - (None) Container user_id definition.
@@ -61,6 +61,10 @@ class AcpypeParamsGMX():
                 properties=None, **kwargs) -> None:
         properties = properties or {}
 
+         # Call parent class constructor
+        super().__init__(properties)
+        self.locals_var_dict = locals().copy()
+
         # Input/Output files
         self.io_dict = { 
             "in": { "input_path": input_path }, 
@@ -70,25 +74,12 @@ class AcpypeParamsGMX():
         # Properties specific for BB
         self.basename = properties.get('basename', 'BBB')
         self.charge = properties.get('charge', '')
-        self.acpype_path = get_binary_path(properties, 'acpype_path')
+        self.binary_path = get_binary_path(properties, 'binary_path')
         self.properties = properties
 
-        # container Specific
-        self.container_path = properties.get('container_path')
-        self.container_image = properties.get('container_image', 'mmbirb/acpype:latest')
-        self.container_volume_path = properties.get('container_volume_path', '/tmp')
-        self.container_working_dir = properties.get('container_working_dir')
-        self.container_user_id = properties.get('container_user_id')
-        self.container_shell_path = properties.get('container_shell_path', '/bin/bash')
-
-        # Properties common in all BB
-        self.can_write_console_log = properties.get('can_write_console_log', True)
-        self.global_log = properties.get('global_log', None)
-        self.prefix = properties.get('prefix', None)
-        self.step = properties.get('step', None)
-        self.path = properties.get('path', '')
-        self.remove_tmp = properties.get('remove_tmp', True)
-        self.restart = properties.get('restart', False)
+        # Check the properties
+        self.check_properties(properties)
+        self.check_arguments()
 
     def check_data_params(self, out_log, err_log):
         """ Checks all the input/output paths and parameters """
@@ -113,7 +104,7 @@ class AcpypeParamsGMX():
             out_pth = get_basename(self.basename, out_log) + '.' + self.unique_name
 
         # executable path
-        instructions_list.append(self.acpype_path)
+        instructions_list.append(self.binary_path)
 
         # generating input 
         ipath = '-i ' + container_io_dict["in"]["input_path"]
@@ -134,56 +125,45 @@ class AcpypeParamsGMX():
     @launchlogger
     def launch(self) -> int:
         """Execute the :class:`AcpypeParamsGMX <acpype.acpype_params_gmx.AcpypeParamsGMX>` acpype.acpype_params_gmx.AcpypeParamsGMX object."""
-        
-        # Get local loggers from launchlogger decorator
-        out_log = getattr(self, 'out_log', None)
-        err_log = getattr(self, 'err_log', None)
 
         # check input/output paths and parameters
-        self.check_data_params(out_log, err_log)
+        self.check_data_params(self.out_log, self.err_log)
 
-        # Check the properties
-        fu.check_properties(self, self.properties)
-
-        if self.restart:
-            output_file_list = [container_io_dict["out"]["output_path_gro"], 
-                                container_io_dict["out"]["output_path_itp"], 
-                                container_io_dict["out"]["output_path_top"]]
-            if fu.check_complete_files(output_file_list):
-                fu.log('Restart is enabled, this step: %s will the skipped' % self.step, out_log, self.global_log)
-                return 0
-
-        # copy inputs to container
-        container_io_dict = fu.copy_to_container(self.container_path, self.container_volume_path, self.io_dict)
+        # Setup Biobb
+        if self.check_restart(): return 0
+        self.stage_files()
 
         # create unique name for temporary folder (created by acpype)
         self.unique_name = create_unique_name(6)
 
         # create command line instruction
-        cmd = self.create_cmd(container_io_dict, out_log, err_log) 
+        self.cmd = self.create_cmd(self.stage_io_dict, self.out_log, self.err_log) 
 
-        # execute cmd
-        fu.log('Running %s, this execution can take a while' % self.acpype_path, out_log)
-        cmd = fu.create_cmd_line(cmd, container_path=self.container_path, host_volume=container_io_dict.get("unique_dir"), container_volume=self.container_volume_path, container_working_dir=self.container_working_dir, container_user_uid=self.container_user_id, container_image=self.container_image, container_shell_path=self.container_shell_path, out_log=out_log, global_log=self.global_log)
-        returncode = cmd_wrapper.CmdWrapper(cmd, out_log, err_log, self.global_log).launch()
+        # Run Biobb block
+        self.run_biobb()
+
+        # Copy files to host
+        self.copy_to_host()
 
         # move files to output_path and removes temporary folder
         if self.container_path:
             process_output_gmx(self.unique_name, 
-                               container_io_dict['unique_dir'], 
+                               self.stage_io_dict['unique_dir'], 
                                self.remove_tmp, 
                                self.basename, 
                                get_default_value(self.__class__.__name__), 
-                               self.output_files, out_log)
+                               self.output_files, self.out_log)
         else:
             process_output_gmx(self.unique_name, 
                                self.basename + "." + self.unique_name + ".acpype", 
                                self.remove_tmp, 
                                self.basename, 
                                get_default_value(self.__class__.__name__), 
-                               self.output_files, out_log)
+                               self.output_files, self.out_log)
 
-        return returncode
+        self.check_arguments(output_files_created=True, raise_exception=False)
+
+        return self.return_code
 
 def acpype_params_gmx(input_path: str, output_path_gro: str, output_path_itp: str, output_path_top: str, properties: dict = None, **kwargs) -> int:
     """Execute the :class:`AcpypeParamsGMX <acpype.acpype_params_gmx.AcpypeParamsGMX>` class and
