@@ -2,13 +2,13 @@
 
 """Module containing the ReduceAddHydrogens class and the command line interface."""
 import argparse
+from biobb_common.generic.biobb_object import BiobbObject
 from biobb_common.configuration import settings
-from biobb_common.tools import file_utils as fu
 from biobb_common.tools.file_utils import launchlogger
-from biobb_common.command_wrapper import cmd_wrapper
 from biobb_chemistry.ambertools.common import *
 
-class ReduceAddHydrogens():
+
+class ReduceAddHydrogens(BiobbObject):
     """
     | biobb_chemistry ReduceAddHydrogens
     | This class is a wrapper of the `Ambertools <http://ambermd.org/doc12/AmberTools12.pdf>`_ reduce module for adding hydrogens to a given structure.
@@ -34,8 +34,10 @@ class ReduceAddHydrogens():
             * **charges** (*bool*) - (False) output charge state for appropriate hydrogen records
             * **dorotmet** (*bool*) - (False) allow methionine methyl groups to rotate (not recommended)
             * **noadjust** (*bool*) - (False) do not process any rot or flip adjustments
+            * **metal_bump** (*float*) - (None) [0~5|0.005] H 'bumps' metals at radius plus this
+            * **non_metal_bump** (*float*) - (None) [0~5|0.005] 'bumps' nonmetal at radius plus this
             * **build** (*bool*) - (False) add H, including His sc NH, then rotate and flip groups (except for pre-existing methionine methyl hydrogens)
-            * **reduce_path** (*str*) - ("reduce") Path to the reduce executable binary.
+            * **binary_path** (*str*) - ("reduce") Path to the reduce executable binary.
             * **remove_tmp** (*bool*) - (True) [WF property] Remove temporal files.
             * **restart** (*bool*) - (False) [WF property] Do not execute if output files exist.
             * **container_path** (*str*) - (None) Container path definition.
@@ -73,6 +75,10 @@ class ReduceAddHydrogens():
                 properties=None, **kwargs) -> None:
         properties = properties or {}
 
+        # Call parent class constructor
+        super().__init__(properties)
+        self.locals_var_dict = locals().copy()
+
         # Input/Output files
         self.io_dict = { 
             "in": { "input_path": input_path }, 
@@ -97,32 +103,26 @@ class ReduceAddHydrogens():
         self.dorotmet = properties.get('dorotmet', False)
         self.noadjust = properties.get('noadjust', False)
         self.build = properties.get('build', False)
-        self.reduce_path = get_binary_path(properties, 'reduce_path')
+        self.metal_bump = properties.get('metal_bump', None)
+        self.non_metal_bump = properties.get('non_metal_bump', None)
+        self.binary_path = get_binary_path(properties, 'binary_path')
         self.properties = properties
 
-        # container Specific
-        self.container_path = properties.get('container_path')
-        self.container_image = properties.get('container_image', 'afandiadib/ambertools:serial')
-        self.container_volume_path = properties.get('container_volume_path', '/tmp')
-        self.container_working_dir = properties.get('container_working_dir')
-        self.container_user_id = properties.get('container_user_id')
-        self.container_shell_path = properties.get('container_shell_path', '/bin/bash')
+        # Check the properties
+        self.check_properties(properties)
+        self.check_arguments()
 
-        # Properties common in all BB
-        self.can_write_console_log = properties.get('can_write_console_log', True)
-        self.global_log = properties.get('global_log', None)
-        self.prefix = properties.get('prefix', None)
-        self.step = properties.get('step', None)
-        self.path = properties.get('path', '')
-        self.remove_tmp = properties.get('remove_tmp', True)
-        self.restart = properties.get('restart', False)
+    def check_data_params(self, out_log, err_log):
+        """ Checks all the input/output paths and parameters """
+        self.io_dict["in"]["input_path"] = check_input_path(self.io_dict["in"]["input_path"], out_log, self.__class__.__name__)
+        self.io_dict["out"]["output_path"] = check_output_path(self.io_dict["out"]["output_path"], out_log, self.__class__.__name__)
 
     def create_cmd(self, container_io_dict, out_log, err_log):
         """Creates the command line instruction using the properties file settings"""
         instructions_list = []
 
         # executable path
-        instructions_list.append(self.reduce_path)
+        instructions_list.append(self.binary_path)
 
         if self.flip: instructions_list.append('-FLIP')
         if self.noflip: instructions_list.append('-NOFLIP')
@@ -142,6 +142,12 @@ class ReduceAddHydrogens():
         if self.noadjust: instructions_list.append('-NOADJust')
         if self.build: instructions_list.append('-BUILD')
 
+        if self.metal_bump:
+            instructions_list.append('-METALBump ' + str(self.metal_bump))
+
+        if self.non_metal_bump:
+            instructions_list.append('-NONMETALBump ' + str(self.non_metal_bump))
+
         instructions_list.append(container_io_dict["in"]["input_path"])
         instructions_list.append('>')
         instructions_list.append(container_io_dict["out"]["output_path"])
@@ -152,43 +158,31 @@ class ReduceAddHydrogens():
     def launch(self) -> int:
         """Execute the :class:`ReduceAddHydrogens <ambertools.reduce_add_hydrogens.ReduceAddHydrogens>` ambertools.reduce_add_hydrogens.ReduceAddHydrogens object."""
        
-        # Get local loggers from launchlogger decorator
-        out_log = getattr(self, 'out_log', None)
-        err_log = getattr(self, 'err_log', None)
+        # check input/output paths and parameters
+        self.check_data_params(self.out_log, self.err_log)
 
-        # Check the properties
-        fu.check_properties(self, self.properties)
+        # Setup Biobb
+        if self.check_restart(): return 0
+        self.stage_files()
 
-        if self.restart:
-            output_file_list = [self.output_path]
-            if fu.check_complete_files(output_file_list):
-                fu.log('Restart is enabled, this step: %s will the skipped' % self.step, out_log, self.global_log)
-                return 0
+        # create command line instruction
+        self.cmd = self.create_cmd(self.stage_io_dict, self.out_log, self.err_log) 
 
-        # copy inputs to container
-        container_io_dict = fu.copy_to_container(self.container_path, self.container_volume_path, self.io_dict)
+        # Run Biobb block
+        self.run_biobb()
 
-        # create cmd and launch execution
-        cmd = self.create_cmd(container_io_dict, out_log, err_log)
-        cmd = fu.create_cmd_line(cmd, container_path=self.container_path, 
-                                 host_volume=container_io_dict.get("unique_dir"), 
-                                 container_volume=self.container_volume_path, 
-                                 container_working_dir=self.container_working_dir, 
-                                 container_user_uid=self.container_user_id, 
-                                 container_image=self.container_image, 
-                                 container_shell_path=self.container_shell_path, 
-                                 out_log=out_log, global_log=self.global_log)
-        returncode = cmd_wrapper.CmdWrapper(cmd, out_log, err_log, self.global_log).launch()
-
-        # copy output(s) to output(s) path(s) in case of container execution
-        fu.copy_to_host(self.container_path, container_io_dict, self.io_dict)
+        # Copy files to host
+        self.copy_to_host()
 
         # remove temporary folder(s)
-        if self.container_path and self.remove_tmp: 
-            fu.rm(container_io_dict['unique_dir'])
-            fu.log('Removed: %s' % str(container_io_dict['unique_dir']), out_log)
+        self.tmp_files.extend([
+            self.stage_io_dict.get("unique_dir")
+        ])
+        self.remove_tmp_files()
 
-        return returncode
+        self.check_arguments(output_files_created=True, raise_exception=False)
+
+        return self.return_code
 
 def reduce_add_hydrogens(input_path: str, output_path: str, properties: dict = None, **kwargs) -> int:
     """Execute the :class:`ReduceAddHydrogens <ambertools.reduce_add_hydrogens.ReduceAddHydrogens>` class and
