@@ -2,13 +2,12 @@
 
 """Module containing the BabelMinimize class and the command line interface."""
 import argparse
+from biobb_common.generic.biobb_object import BiobbObject
 from biobb_common.configuration import  settings
-from biobb_common.tools import file_utils as fu
 from biobb_common.tools.file_utils import launchlogger
-from biobb_common.command_wrapper import cmd_wrapper
 from biobb_chemistry.babelm.common import *
 
-class BabelMinimize():
+class BabelMinimize(BiobbObject):
     """
     | biobb_chemistry BabelMinimize
     | This class is a wrapper of the Open Babel tool.
@@ -27,7 +26,7 @@ class BabelMinimize():
             * **rvdw** (*float*) - (6.0) [0~50|1.0] VDW cut-off distance.
             * **rele** (*float*) - (10.0) [0~50|1.0] Electrostatic cut-off distance.
             * **frequency** (*int*) - (10) [0~50|1] Frequency to update the non-bonded pairs.
-            * **obminimize_path** (*str*) - ("obminimize") Path to the obminimize executable binary.
+            * **binary_path** (*str*) - ("obminimize") Path to the obminimize executable binary.
             * **remove_tmp** (*bool*) - (True) [WF property] Remove temporal files.
             * **restart** (*bool*) - (False) [WF property] Do not execute if output files exist.
             * **container_path** (*str*) - (None) Container path definition.
@@ -65,10 +64,14 @@ class BabelMinimize():
                 properties=None, **kwargs) -> None:
         properties = properties or {}
 
+        # Call parent class constructor
+        super().__init__(properties)
+        self.locals_var_dict = locals().copy()
+
         # Input/Output files
         self.io_dict = { 
-            "in": { "input_path": check_input_path_minimize(input_path, self.__class__.__name__) }, 
-            "out": { "output_path": check_output_path_minimize(output_path, self.__class__.__name__) } 
+            "in": { "input_path": input_path }, 
+            "out": { "output_path": output_path } 
         }
 
         # Properties specific for BB
@@ -81,32 +84,24 @@ class BabelMinimize():
         self.rvdw = properties.get('rvdw', '')
         self.rele = properties.get('rele', '')
         self.frequency = properties.get('frequency', '')
-        self.obminimize_path = get_binary_path(properties, 'obminimize_path')
+        self.binary_path = properties.get('binary_path', 'obminimize')
         self.properties = properties
 
-        # container Specific
-        self.container_path = properties.get('container_path')
-        self.container_image = properties.get('container_image', 'informaticsmatters/obabel:latest')
-        self.container_volume_path = properties.get('container_volume_path', '/tmp')
-        self.container_working_dir = properties.get('container_working_dir')
-        self.container_user_id = properties.get('container_user_id')
-        self.container_shell_path = properties.get('container_shell_path', '/bin/bash')
+        # Check the properties
+        self.check_properties(properties)
+        self.check_arguments()
 
-        # Properties common in all BB
-        self.can_write_console_log = properties.get('can_write_console_log', True)
-        self.global_log = properties.get('global_log', None)
-        self.prefix = properties.get('prefix', None)
-        self.step = properties.get('step', None)
-        self.path = properties.get('path', '')
-        self.remove_tmp = properties.get('remove_tmp', True)
-        self.restart = properties.get('restart', False)
+    def check_data_params(self, out_log, err_log):
+        """ Checks all the input/output paths and parameters """
+        self.io_dict["in"]["input_path"] = check_input_path_minimize(self.io_dict["in"]["input_path"], out_log, self.__class__.__name__)
+        self.io_dict["out"]["output_path"] = check_output_path_minimize(self.io_dict["out"]["output_path"], out_log, self.__class__.__name__)
 
     def create_cmd(self, container_io_dict, out_log, err_log):
         """Creates the command line instruction using the properties file settings"""
         instructions_list = []
 
         # executable path
-        instructions_list.append(self.obminimize_path)
+        instructions_list.append(self.binary_path)
 
         # check all properties
         if check_minimize_property("criteria", self.criteria, out_log): instructions_list.append('-c ' + str(self.criteria))
@@ -144,43 +139,31 @@ class BabelMinimize():
     def launch(self) -> int:
         """Execute the :class:`BabelMinimize <babelm.babel_minimize.BabelMinimize>` babelm.babel_minimize.BabelMinimize object."""
         
-        # Get local loggers from launchlogger decorator
-        out_log = getattr(self, 'out_log', None)
-        err_log = getattr(self, 'err_log', None)
+        # check input/output paths and parameters
+        self.check_data_params(self.out_log, self.err_log)
 
-        # Check the properties
-        fu.check_properties(self, self.properties)
+        # Setup Biobb
+        if self.check_restart(): return 0
+        self.stage_files()
 
-        if self.restart:
-            output_file_list = [self.io_dict["out"]["output_path"]]
-            if fu.check_complete_files(output_file_list):
-                fu.log('Restart is enabled, this step: %s will the skipped' % self.step, out_log, self.global_log)
-                return 0
+        # create command line instruction
+        self.cmd = self.create_cmd(self.stage_io_dict, self.out_log, self.err_log) 
 
-        # copy inputs to container
-        container_io_dict = fu.copy_to_container(self.container_path, self.container_volume_path, self.io_dict)
+        # Run Biobb block
+        self.run_biobb()
 
-        # create and execute command line instruction
-        cmd = self.create_cmd(container_io_dict, out_log, err_log) 
-        cmd = fu.create_cmd_line(cmd, container_path=self.container_path, 
-                                 host_volume=container_io_dict.get("unique_dir"), 
-                                 container_volume=self.container_volume_path, 
-                                 container_working_dir=self.container_working_dir, 
-                                 container_user_uid=self.container_user_id, 
-                                 container_image=self.container_image, 
-                                 container_shell_path=self.container_shell_path, 
-                                 out_log=out_log, global_log=self.global_log)
-        returncode = cmd_wrapper.CmdWrapper(cmd, out_log, err_log, self.global_log).launch()
-
-        # copy output(s) to output(s) path(s) in case of container execution
-        fu.copy_to_host(self.container_path, container_io_dict, self.io_dict)
+        # Copy files to host
+        self.copy_to_host()
 
         # remove temporary folder(s)
-        if self.container_path and self.remove_tmp: 
-            fu.rm(container_io_dict['unique_dir'])
-            fu.log('Removed: %s' % str(container_io_dict['unique_dir']), out_log)
+        self.tmp_files.extend([
+            self.stage_io_dict.get("unique_dir")
+        ])
+        self.remove_tmp_files()
 
-        return returncode
+        self.check_arguments(output_files_created=True, raise_exception=False)
+
+        return self.return_code
 
 def babel_minimize(input_path: str, output_path: str, properties: dict = None, **kwargs) -> int:
     """Execute the :class:`BabelMinimize <babelm.babel_minimize.BabelMinimize>` class and
