@@ -4,39 +4,54 @@ import re
 from biobb_common.tools import file_utils as fu
 
 
-def check_input_path(path, classname):
+def check_input_path(path, out_log, classname):
 	""" Checks input file """ 
 	if not Path(path).exists():
+		fu.log(classname + ': Unexisting input file, exiting', out_log)
 		raise SystemExit(classname + ': Unexisting input file')
 	file_extension = PurePath(path).suffix
 	if not is_valid_input(file_extension[1:]):
+		fu.log(classname + ': Format %s in input file is not compatible' % file_extension[1:], out_log)
 		raise SystemExit(classname + ': Format %s in input file is not compatible' % file_extension[1:])
+	if(PurePath(path).name == path or not PurePath(path).is_absolute()):
+		path = str(PurePath(Path.cwd()).joinpath(path))
+
 	return path
 
-def check_output_path(path, classname):
-	""" Checks output path and file """ 
+def check_output_path(path, out_log, classname):
+	""" Checks output path """ 
 	if PurePath(path).parent and not Path(PurePath(path).parent).exists():
-		raise SystemExit(classname + ': Unexisting output folder')
+		fu.log(classname + ': Unexisting output %s output folder, exiting' % type, out_log)
+		raise SystemExit(classname + ': Unexisting %s output folder' % type)
 	file_extension = PurePath(path).suffix
 	if not is_valid_input(file_extension[1:]):
+		fu.log(classname + ': Format %s in input file is not compatible' % file_extension[1:], out_log)
 		raise SystemExit(classname + ': Format %s in output file is not compatible' % file_extension[1:])
+
 	return path
 
-def check_input_path_minimize(path, classname):
+def check_input_path_minimize(path, out_log, classname):
 	""" Checks input file """ 
 	if not Path(path).exists():
+		fu.log(classname + ': Unexisting input file, exiting', out_log)
 		raise SystemExit(classname + ': Unexisting input file')
 	file_extension = PurePath(path).suffix
 	if not is_valid_input_minimize(file_extension[1:]):
+		fu.log(classname + ': Format %s in input file is not compatible' % file_extension[1:], out_log)
 		raise SystemExit(classname + ': Format %s in input file is not compatible' % file_extension[1:])
+	if(PurePath(path).name == path or not PurePath(path).is_absolute()):
+		path = str(PurePath(Path.cwd()).joinpath(path))
+
 	return path
 
-def check_output_path_minimize(path, classname):
-	""" Checks output path and file """ 
+def check_output_path_minimize(path, out_log, classname):
+	""" Checks output path """ 
 	if PurePath(path).parent and not Path(PurePath(path).parent).exists():
-		raise SystemExit(classname + ': Unexisting output folder')
+		fu.log(classname + ': Unexisting output %s output folder, exiting' % type, out_log)
+		raise SystemExit(classname + ': Unexisting %s output folder' % type)
 	file_extension = PurePath(path).suffix
 	if not is_valid_input_minimize(file_extension[1:]):
+		fu.log(classname + ': Format %s in input file is not compatible' % file_extension[1:], out_log)
 		raise SystemExit(classname + ': Format %s in output file is not compatible' % file_extension[1:])
 	return path
 
@@ -60,7 +75,7 @@ def check_minimize_property(type, value, out_log):
 
 	if type == "criteria":
 
-		if re.match('(\d+(\.\d+)?)', value) or re.match('[+\-]?(?:0|[1-9]\d*)(?:\.\d*)?(?:[eE][+\-]?\d+)?', value):
+		if re.match(r'(\d+(\.\d+)?)', value) or re.match(r'[+\-]?(?:0|[1-9]\d*)(?:\.\d*)?(?:[eE][+\-]?\d+)?', value):
 			return True
 		else:
 			fu.log('Criteria %s is not correct, assigned default value: %s' % (value, get_default_value('criteria')), out_log)
@@ -86,7 +101,7 @@ def check_minimize_property(type, value, out_log):
 			fu.log('Hydrogens %s is not correct, assigned default value: %s' % (value, get_default_value('hydrogens')), out_log)
 
 	if type == "steps":
-		if re.match('^\d+$', value):
+		if re.match(r'^\d+$', value):
 			return True
 		else:
 			fu.log('Steps %s is not correct, assigned default value: %s' % (value, get_default_value('steps')), out_log)
@@ -100,19 +115,19 @@ def check_minimize_property(type, value, out_log):
 			fu.log('Cut-off %s is not correct, assigned default value: %s' % (value, get_default_value('cutoff')), out_log)
 
 	if type == "rvdw":
-		if re.match('(\d+(\.\d+)?)', value):
+		if re.match(r'(\d+(\.\d+)?)', value):
 			return True
 		else:
 			fu.log('Rvdw %s is not correct, assigned default value: %s' % (value, get_default_value('rvdw')), out_log)
 
 	if type == "rele":
-		if re.match('(\d+(\.\d+)?)', value):
+		if re.match(r'(\d+(\.\d+)?)', value):
 			return True
 		else:
 			fu.log('Rele %s is not correct, assigned default value: %s' % (value, get_default_value('rele')), out_log)
 
 	if type == "frequency":
-		if re.match('^\d+$', value):
+		if re.match(r'^\d+$', value):
 			return True
 		else:
 			fu.log('Frequency %s is not correct, assigned default value: %s' % (value, get_default_value('frequency')), out_log)
